@@ -21,7 +21,7 @@ def augmentation():
     "--text",
     type=click.STRING,
     required=True,
-    help="text to be detected",
+    help="text to be augmented",
 )
 @click.option(
     "-n",
