@@ -586,7 +586,7 @@ async def upload_dataset(
     task = progress_bar.add_task(description="", total=Total_number_examples)
     progress_bar.update(task)
     animation_tracker = 1
-    for chunk_id, example in enumerate(nlu_data):
+    for chunk_id, example in enumerate(nlu_data[skip_first:]):
         progress_bar.start()
         current_example_number += 1
         batch = {PROJECT_ID: project_id, LANGUAGE: language, EXAMPLE: example}
