@@ -1,8 +1,3 @@
-from dataclasses import dataclass
-from typing import Dict, Text
-
-import datasets
-
 LANGUAGE_CATALOG_URL = "api/nlu/v1/supported-languages"
 CREATE_EXAMPLE_URL = "api/nlu/v1/single/example"
 CREATE_PROJECT_URL = "api/nlu/v1/project"
@@ -140,11 +135,3 @@ C_DEAD = "⚫"
 
 # DEFAULT VALUES
 DEFAULT_RASA_TRAINING_JOBS = 1
-
-
-@dataclass
-class HuggingfaceDatasetCollection:
-    subset: Text
-    ner_dict: Dict
-    train_dataset: datasets.arrow_dataset.Dataset
-    test_dataset: datasets.arrow_dataset.Dataset
